**Example 1: 示例1**



Input: 

```
tccli keewidb CleanUpInstance --cli-unfold-argument  \
    --InstanceId kee-g0jmitf7
```

Output: 
```
{
    "Response": {
        "RequestId": "3329c145-ece6-445a-a1f1-738f591ddbdd",
        "TaskId": 1634784476
    }
}
```

